@@ -15,3 +15,6 @@ class ForceTorque:
 
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
+
+    def __repr__(self):
+        return f"ForceTorque<force={self.force}, torque={self.torque}>"
