@@ -1,5 +1,6 @@
 import math
 
+
 class RobotState:
 
     def __init__(self, state: str, moving: bool, active: bool, target_speed: float, actual_speed: float, _type: str = ''):
@@ -34,7 +35,7 @@ class RobotState:
         elif state == 1:
             return "Stopped", False, False
         elif state == 2:
-            return "Playing", True, True
+            return "Running", True, True
         elif state == 3:
             return "Pausing", True, False
         elif state == 4:
@@ -51,7 +52,7 @@ class RobotStateChange:
     STOP = 'stop'
 
     def __init__(self, state: str, speed: float, _type: str = ''):
-        assert state in [RobotStateChange.START, RobotStateChange.PAUSE, RobotStateChange.STOP]
+        # assert state in [RobotStateChange.START, RobotStateChange.PAUSE, RobotStateChange.STOP]
         self._type = 'robot_state_change'
         self.state = state
         self.speed = speed
