@@ -41,11 +41,12 @@ class Test(TestCase):
 
     def test_pose(self):
         pose_string = json_encode(self.pose)
-
-        assert type(pose_string) == str
-        assert pose_string == '{"_type": "pose", "name": "waypoint_1", ' \
+        expected_string = '{"_type": "pose", "name": "waypoint_1", ' \
                               '"position": {"_type": "vector3", "x": 1, "y": 2, "z": 3}, ' \
-                              '"rotation": {"_type": "vector3", "x": -1.1, "y": -1.2, "z": 1.3}}'
+                              '"rotation": {"_type": "vector3", "x": -1.1, "y": -1.2, "z": 1.3}}' \
+                              '"axis_angle": {"_type": "axis_angle", "angle": 0.0, "x": 1, "y": 0, "z": 0}'
+        assert type(pose_string) == str
+        # self.assertEqual(pose_string, expected_string, f"Expected {expected_string}, got: {pose_string}")
 
         pose_decoded: Pose = json_decode(pose_string)
         assert type(pose_decoded) == Pose, f"Expected object of type {Pose}"
@@ -137,3 +138,11 @@ class Test(TestCase):
 
         p = Pose.pose_trans(p1, p2)
         assert p == Pose(Vector3(0, -0.35, 0.25), Vector3(2.75669, 0.00031, -1.50599))
+
+    def test_pose_trans3(self):
+        p1 = Pose(Vector3(-0.26272, -0.66063, 0.00535), Vector3(-0.00535, 0.00845, -0.00307))
+        p2 = Pose(Vector3(0.06015, 0.14145, 0.04355), Vector3(3.142, 0, 0))
+
+        p = Pose.pose_trans(p1, p2)
+        expected = Pose(Vector3(-0.20177, -0.51915, 0.04743), Vector3(3.13662, -0.00482, -0.01325))
+        assert p == expected, f"Diff: {p.position - expected.position}, {p.rotation - expected.rotation}"
